; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.

;-| Super Motions |--------------------------------------------------------
; DM1
[Command]
name = "Power_x"
command = ~D, DF, F, D, DF, F, x
time = 40

; DM1
[Command]
name = "power_y"
command = ~D, DF, F, D, DF, F, y
time = 40

; DM1
[Command]
name = "power_z"
command = ~D, DF, F, D, DF, F, z
time = 40

; DM2
[Command]
name = "mad_slash_a"
command = ~D, DF, F, D, DF, F, a
time = 40

; DM2
[Command]
name = "mad_slash_b"
command = ~D, DF, F, D, DF, F, b
time = 40

; DM2
[Command]
name = "mad_slash_c"
command = ~D, DF, F, D, DF, F, c
time = 40

; DM1
[Command]
name = "high_a"
command = ~D, DB, B, D, DB, B, a
time = 40

; DM1
[Command]
name = "high_b"
command = ~D, DB, B, D, DB, B, b
time = 40

; DM1
[Command]
name = "high_c"
command = ~D, DB, B, D, DB, B, c
time = 40

;-| Special Motions |------------------------------------------------------
;-----------------
; QCFQCB
[Command]
name = "QCFQCB_x"
command = ~D, DF, F, D, DB, B, x
time = 60

; QCFQCB
[Command]
name = "QCFQCB_y"
command = ~D, DF, F, D, DB, B, y
time = 60

; QCFQCB
[Command]
name = "QCFQCB_z"
command = ~D, DF, F, D, DB, B, z
time = 60

; QCF
[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCF_x"
command = ~D, DF, F, x
time = 15

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_z"
command = ~D, DF, F, z

;-----------------
; QCB
[Command]
name = "QCB_a"
command = ~D, DB, B, a
time = 15

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_z"
command = ~D, DB, B, z

;-----------------
; Uppercut
[Command]
name = "uppercut_a"
command = ~F, D, DF, a

[Command]
name = "uppercut_b"
command = ~F, D, DF, b

[Command]
name = "uppercut_c"
command = ~F, D, DF, c

[Command]
name = "uppercut_x"
command = ~F, D, DF, x

[Command]
name = "uppercut_y"
command = ~F, D, DF, y

[Command]
name = "uppercut_z"
command = ~F, D, DF, z

[Command]
name = "3p1_x"
command = ~D, DB, B, x

[Command]
name = "3p1_y"
command = ~D, DB, B, y

[Command]
name = "3p1_z"
command = ~D, DB, B, z

;--------------------
;Charge_Down_up
[Command]
name = "chargedownup_a"
command = ~60$D, U, a
time = 10

[Command]
name = "chargedownup_b"
command = ~60$D, U, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10

;--------------------
;Charge_Back_fwd
[Command]
name = "chargebackfwd_a"
command = ~60$B, F, a
time = 10

[Command]
name = "chargebackfwd_b"
command = ~60$B, F, b
time = 10

[Command]
name = "chargedownup_c"
command = ~60$D, U, c
time = 10

[Command]
name = "chargedownup_x"
command = ~60$D, U, x
time = 10

[Command]
name = "chargedownup_y"
command = ~60$D, U, y
time = 10

[Command]
name = "chargedownup_z"
command = ~60$D, U, z
time = 10



;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

[Command]
name = "DD";Required (do not remove)
command = D, D
time = 10

[Command]
name = "UU";Required (do not remove)
command = U, U
time = 10
;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "bc"
command = b+c
time = 1

[Command]
name = "xy"
command = x+y
time = 1

[Command]
name = "yz"
command = y+z
time = 1
;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "back"
command = B
time = 1

[Command]
name = "upback"
command = UB
time = 1

[Command]
name = "downback"
command = DB
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "chargex"
command = ~F, F, x
time = 20

[Command]
name = "chargey"
command = ~F, F, y
time = 20

[Command]
name = "chargez"
command = ~F, F, z
time = 20

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "hold_a"
command = /$a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "hold_b"
command = /$b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "hold_x"
command = /$x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "hold_y"
command = /$y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "hold_z"
command = /$z
time = 1

[Command]
name = "s"
command = s
time = 1

[Command]
name = "s"
command = s
time = 1
;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;Power Gyser_x
[State -1]
type = ChangeState
value = 3000
triggerall = command = "Power_x"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;Double Gyser_y
[State -1]
type = ChangeState
value = 3200
triggerall = command = "power_y"
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;Triple Gyser_z
[State -1]
type = ChangeState
value = 3100
triggerall = command = "power_z"
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;High Angle Gyser A
[State -1]
type = ChangeState
value = 10000
triggerall = command = "high_a"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;High Angle Gyser B
[State -1]
type = ChangeState
value = 11000
triggerall = command = "high_b"
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;High Angle Gyser C
[State -1]
type = ChangeState
value = 12000
triggerall = command = "high_c"
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;Super Punch_a
[State -1]
type = ChangeState
value = 2500
triggerall = command = "mad_slash_c"
triggerall = power >= 3000
triggerall = P2bodydist X > 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;===========================================================================
;Super Punch_a
[State -1]
type = ChangeState
value = 2510
triggerall = command = "mad_slash_c"
triggerall = power >= 3000
triggerall = P2bodydist X < 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;Super Punch_a
[State -1]
type = ChangeState
value = 2300
triggerall = command = "mad_slash_b"
triggerall = power >= 2000
triggerall = P2bodydist X > 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;===========================================================================
;Super Punch_a
[State -1]
type = ChangeState
value = 2310
triggerall = command = "mad_slash_b"
triggerall = power >= 2000
triggerall = P2bodydist X < 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;Super Punch_a
[State -1]
type = ChangeState
value = 2000
triggerall = command = "mad_slash_a"
triggerall = power >= 1000
triggerall = P2bodydist X > 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;===========================================================================
;Super Punch_a
[State -1]
type = ChangeState
value = 2100
triggerall = command = "mad_slash_a"
triggerall = power >= 1000
triggerall = P2bodydist X < 70
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
;Burning knuckles_x
[State -1]
type = ChangeState
value = 800
triggerall = command = "QCB_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1
;---------------------------------------------------------------------------
;Burning knuckles_y
[State -1]
type = ChangeState
value = 810
triggerall = command = "QCB_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------
;Burning knuckles_z
[State -1]
type = ChangeState
value = 820
triggerall = command = "QCB_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;Top attack
[State -1]
type = ChangeState
value = 8000
triggerall = command = "ab"
triggerall = var(20) = 1
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

; Power Charge (start)
[State -1]
type = ChangeState
value = 4000
triggerall = command = "chargex"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

; Power Charge (start)
[State -1]
type = ChangeState
value = 4100
triggerall = command = "chargey"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

; Power Charge (start)
[State -1]
type = ChangeState
value = 4200
triggerall = command = "chargez"
trigger1 = statetype != A
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------
;Crack Shoot_a
[State -1]
type = ChangeState
value = 1100
triggerall = command = "QCB_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------
;Crack Shoot_b
[State -1]
type = ChangeState
value = 1120
triggerall = command = "QCB_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------
;Crack Shoot_c
[State -1]
type = ChangeState
value = 1130
triggerall = command = "QCB_c"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------
;Power Dung_a
[State -1]
type = ChangeState
value = 1700
triggerall = command = "uppercut_a"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1
;---------------------------------------------------------------------------
;Power Dung_b
[State -1]
type = ChangeState
value = 1710
triggerall = command = "uppercut_b"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1
;---------------------------------------------------------------------------
;Power Dung_c
[State -1]
type = ChangeState
value = 1720
triggerall = command = "uppercut_c"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------
;fireball_x
[State -1]
type = ChangeState
value = 500
triggerall = command = "QCF_x"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 250
trigger9 = movecontact = 1
trigger10 = stateno = 240
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------
;fireball_y
[State -1]
type = ChangeState
value = 501
triggerall = command = "QCF_y"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;---------------------------------------------------------------------------
;fireball_z
[State -1]
type = ChangeState
value = 502
triggerall = command = "QCF_z"
triggerall = numproj = 0
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 235
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 250
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1
trigger17 = stateno = 245
trigger17 = movecontact = 1

;Roll fwd 
[State -1]
type = ChangeState
value = 900
triggerall = command = "xy"
triggerall = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Roll back AB (during guard)
[State -1]
type = ChangeState
value = 920
triggerall = command = "xy"
triggerall = command = "holdback"
triggerall = power >= 500
trigger1 = stateno = 150
trigger2 = stateno = 152

;Roll fwd AB (during guard)
[State -1]
type = ChangeState
value = 910
triggerall = command = "xy"
triggerall = command = "holdfwd"
triggerall = power >= 500
trigger1 = stateno = 150
trigger2 = stateno = 152

;Roll fwd AB (during guard)
[State -1]
type = ChangeState
value = 910
triggerall = command = "xy"
triggerall = power >= 500
trigger1 = stateno = 150
trigger2 = stateno = 152

;---------------------------------------------------------------------------
;Roll back
[State -1]
type = ChangeState
value = 901
triggerall = command = "xy"
triggerall = command = "holdback"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Roll Fwd
[State -1]
type = ChangeState
value = 900
triggerall = command = "xy"
triggerall = stateno != 250
trigger1 = statetype = S
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw (close dir+b)
; Complicated? Skip the throws and look at stand_a, etc, first.
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = ChangeState
value = 950
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = p2bodydist X < 5 ;Near P2
trigger1 = command = "fwd_z";p2 stand
trigger1 = stateno != 100    ;Not running
trigger1 = p2statetype = S
trigger1 = p2movetype != H
trigger2 = command = "fwd_b";p2 crouch
trigger2 = stateno != 100    ;Not running
trigger2 = p2statetype = C
trigger2 = p2movetype != H
trigger3 = command = "back_b";p2 stand
trigger3 = p2statetype = S
trigger3 = p2movetype != H
trigger4 = command = "back_b";p2 crouch
trigger4 = p2statetype = C
trigger4 = p2movetype != H

;---------------------------------------------------------------------------
;Air_Throw1 (close dir+b)
; This is disabled right now. Remove the "null;" below when you
; want to use it.
[State -1]
type = null; ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_b"
trigger2 = command = "back_b"

;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 200
triggerall = command = "a";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = P2bodydist X >= 15
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 230
trigger6 = movecontact = 1
trigger7 = stateno = 235
trigger7 = movecontact = 1
trigger8 = stateno = 240
trigger8 = movecontact = 1
trigger9 = stateno = 250
trigger9 = movecontact = 1
trigger10 = stateno = 400
trigger10 = movecontact = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1
trigger12 = stateno = 420
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 440
trigger14 = movecontact = 1
trigger15 = stateno = 450
trigger15 = movecontact = 1

;Stand_A
[State -1]
type = ChangeState
value = 205
triggerall = command = "a";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = P2bodydist X <= 15
trigger1 = statetype = S
trigger1 = ctrl = 1
 ;Uncomment the following if you want to be able to do a Stand_A rapidly
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 230
trigger6 = movecontact = 1
trigger7 = stateno = 235
trigger7 = movecontact = 1
trigger8 = stateno = 240
trigger8 = movecontact = 1
trigger9 = stateno = 250
trigger9 = movecontact = 1
trigger10 = stateno = 400
trigger10 = movecontact = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1
trigger12 = stateno = 420
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 440
trigger14 = movecontact = 1
trigger15 = stateno = 450
trigger15 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2bodydist X > 15
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 200
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 230
trigger6 = movecontact = 1
trigger7 = stateno = 235
trigger7 = movecontact = 1
trigger8 = stateno = 240
trigger8 = movecontact = 1
trigger9 = stateno = 250
trigger9 = movecontact = 1
trigger10 = stateno = 400
trigger10 = movecontact = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1
trigger12 = stateno = 420
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 440
trigger14 = movecontact = 1
trigger15 = stateno = 450
trigger15 = movecontact = 1

;---------------------------------------------------------------------------

;Stand_B (close)
[State -1]
type = ChangeState
value = 215
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 15
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 215
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 200
trigger5 = movecontact = 1
trigger6 = stateno = 230
trigger6 = movecontact = 1
trigger7 = stateno = 235
trigger7 = movecontact = 1
trigger8 = stateno = 240
trigger8 = movecontact = 1
trigger9 = stateno = 250
trigger9 = movecontact = 1
trigger10 = stateno = 400
trigger10 = movecontact = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1
trigger12 = stateno = 420
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 440
trigger14 = movecontact = 1
trigger15 = stateno = 450
trigger15 = movecontact = 1

;---------------------------------------------------------------------------

;Stand_C
[State -1]
type = ChangeState
value = 219
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 235
trigger2 = movecontact = 1
trigger3 = stateno = 250
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 215
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 200
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger10 = movecontact = 1
trigger10 = stateno = 200
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1

;---------------------------------------------------------------------------

;Stand_X
[State -1]
type = ChangeState
value = 230
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2bodydist X > 15
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 230
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 200
trigger6 = movecontact = 1
trigger7 = stateno = 235
trigger7 = movecontact = 1
trigger8 = stateno = 240
trigger8 = movecontact = 1
trigger9 = stateno = 250
trigger9 = movecontact = 1
trigger10 = stateno = 400
trigger10 = movecontact = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1
trigger12 = stateno = 420
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 440
trigger14 = movecontact = 1
trigger15 = stateno = 450
trigger15 = movecontact = 1

;Stand_X (close)
[State -1]
type = ChangeState
value = 235
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = P2bodydist X <= 15
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 235
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 200
trigger6 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 240
trigger8 = movecontact = 1
trigger9 = stateno = 250
trigger9 = movecontact = 1
trigger10 = stateno = 400
trigger10 = movecontact = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1
trigger12 = stateno = 420
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 440
trigger14 = movecontact = 1
trigger15 = stateno = 450
trigger15 = movecontact = 1

;Stand_Y
[State -1]
type = ChangeState
value = 240
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger6 = stateno = 200
trigger6 = movecontact = 1
trigger7 = stateno = 235
trigger7 = movecontact = 1
trigger8 = stateno = 230
trigger8 = movecontact = 1
trigger9 = stateno = 250
trigger9 = movecontact = 1
trigger10 = stateno = 400
trigger10 = movecontact = 1
trigger11 = stateno = 410
trigger11 = movecontact = 1
trigger12 = stateno = 420
trigger12 = movecontact = 1
trigger13 = stateno = 430
trigger13 = movecontact = 1
trigger14 = stateno = 440
trigger14 = movecontact = 1
trigger15 = stateno = 450
trigger15 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_Z 
[State -1]
type = ChangeState
value = 250
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 250
trigger2 = movecontact = 1
trigger3 = stateno = 205
trigger3 = movecontact = 1
trigger4 = stateno = 210
trigger4 = movecontact = 1
trigger5 = stateno = 215
trigger5 = movecontact = 1
trigger7 = stateno = 230
trigger7 = movecontact = 1
trigger8 = stateno = 200
trigger8 = movecontact = 1
trigger9 = stateno = 240
trigger9 = movecontact = 1
trigger10 = stateno = 235
trigger10 = movecontact = 1
trigger11 = stateno = 400
trigger11 = movecontact = 1
trigger12 = stateno = 410
trigger12 = movecontact = 1
trigger13 = stateno = 420
trigger13 = movecontact = 1
trigger14 = stateno = 430
trigger14 = movecontact = 1
trigger15 = stateno = 440
trigger15 = movecontact = 1
trigger16 = stateno = 450
trigger16 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_A
[State -1]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 450
trigger2 = movecontact = 1
trigger3 = stateno = 440
trigger3 = movecontact = 1
trigger4 = stateno = 430
trigger4 = movecontact = 1
trigger5 = stateno = 420
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 3000
trigger8 = movecontact = 1
trigger9 = stateno = 3200
trigger9 = movecontact = 1
trigger10 = stateno = 3100
trigger10 = movecontact = 1
trigger11 = stateno = 2500
trigger11 = movecontact = 1
trigger12 = stateno = 2510
trigger12 = movecontact = 1
trigger13 = stateno = 2300
trigger13 = movecontact = 1
trigger14 = stateno = 2310
trigger14 = movecontact = 1
trigger15 = stateno = 2000
trigger15 = movecontact = 1
trigger16 = stateno = 2100
trigger16 = movecontact = 1
trigger17 = stateno = 800
trigger17 = movecontact = 1
trigger18 = stateno = 810
trigger18 = movecontact = 1
trigger19 = stateno = 820
trigger19 = movecontact = 1
trigger20 = stateno = 800
trigger20 = movecontact = 1
trigger21 = stateno = 1100
trigger21 = movecontact = 1
trigger22 = stateno = 500
trigger22 = movecontact = 1
trigger23 = stateno = 501
trigger23 = movecontact = 1
trigger24 = stateno = 502
trigger24 = movecontact = 1
trigger25 = stateno = 1120
trigger25 = movecontact = 1
trigger26 = stateno = 1130
trigger26 = movecontact = 1
trigger27 = stateno = 1700
trigger27 = movecontact = 1
trigger28 = stateno = 1710
trigger28 = movecontact = 1
trigger29 = stateno = 1720
trigger29 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch_B
[State -1]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 450
trigger2 = movecontact = 1
trigger3 = stateno = 440
trigger3 = movecontact = 1
trigger4 = stateno = 430
trigger4 = movecontact = 1
trigger5 = stateno = 420
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 3000
trigger8 = movecontact = 1
trigger9 = stateno = 3200
trigger9 = movecontact = 1
trigger10 = stateno = 3100
trigger10 = movecontact = 1
trigger11 = stateno = 2500
trigger11 = movecontact = 1
trigger12 = stateno = 2510
trigger12 = movecontact = 1
trigger13 = stateno = 2300
trigger13 = movecontact = 1
trigger14 = stateno = 2310
trigger14 = movecontact = 1
trigger15 = stateno = 2000
trigger15 = movecontact = 1
trigger16 = stateno = 2100
trigger16 = movecontact = 1
trigger17 = stateno = 800
trigger17 = movecontact = 1
trigger18 = stateno = 810
trigger18 = movecontact = 1
trigger19 = stateno = 820
trigger19 = movecontact = 1
trigger20 = stateno = 800
trigger20 = movecontact = 1
trigger21 = stateno = 1100
trigger21 = movecontact = 1
trigger22 = stateno = 500
trigger22 = movecontact = 1
trigger23 = stateno = 501
trigger23 = movecontact = 1
trigger24 = stateno = 502
trigger24 = movecontact = 1
trigger25 = stateno = 1120
trigger25 = movecontact = 1
trigger26 = stateno = 1130
trigger26 = movecontact = 1
trigger27 = stateno = 1700
trigger27 = movecontact = 1
trigger28 = stateno = 1710
trigger28 = movecontact = 1
trigger29 = stateno = 1720
trigger29 = movecontact = 1
;---------------------------------------------------------------------------
;Crouch_C
[State -1]
type = ChangeState
value = 420
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 450
trigger2 = movecontact = 1
trigger3 = stateno = 440
trigger3 = movecontact = 1
trigger4 = stateno = 430
trigger4 = movecontact = 1
trigger5 = stateno = 420
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 3000
trigger8 = movecontact = 1
trigger9 = stateno = 3200
trigger9 = movecontact = 1
trigger10 = stateno = 3100
trigger10 = movecontact = 1
trigger11 = stateno = 2500
trigger11 = movecontact = 1
trigger12 = stateno = 2510
trigger12 = movecontact = 1
trigger13 = stateno = 2300
trigger13 = movecontact = 1
trigger14 = stateno = 2310
trigger14 = movecontact = 1
trigger15 = stateno = 2000
trigger15 = movecontact = 1
trigger16 = stateno = 2100
trigger16 = movecontact = 1
trigger17 = stateno = 800
trigger17 = movecontact = 1
trigger18 = stateno = 810
trigger18 = movecontact = 1
trigger19 = stateno = 820
trigger19 = movecontact = 1
trigger20 = stateno = 800
trigger20 = movecontact = 1
trigger21 = stateno = 1100
trigger21 = movecontact = 1
trigger22 = stateno = 500
trigger22 = movecontact = 1
trigger23 = stateno = 501
trigger23 = movecontact = 1
trigger24 = stateno = 502
trigger24 = movecontact = 1
trigger25 = stateno = 1120
trigger25 = movecontact = 1
trigger26 = stateno = 1130
trigger26 = movecontact = 1
trigger27 = stateno = 1700
trigger27 = movecontact = 1
trigger28 = stateno = 1710
trigger28 = movecontact = 1
trigger29 = stateno = 1720
trigger29 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_X
[State -1]
type = ChangeState
value = 430
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 450
trigger2 = movecontact = 1
trigger3 = stateno = 440
trigger3 = movecontact = 1
trigger4 = stateno = 430
trigger4 = movecontact = 1
trigger5 = stateno = 420
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 3000
trigger8 = movecontact = 1
trigger9 = stateno = 3200
trigger9 = movecontact = 1
trigger10 = stateno = 3100
trigger10 = movecontact = 1
trigger11 = stateno = 2500
trigger11 = movecontact = 1
trigger12 = stateno = 2510
trigger12 = movecontact = 1
trigger13 = stateno = 2300
trigger13 = movecontact = 1
trigger14 = stateno = 2310
trigger14 = movecontact = 1
trigger15 = stateno = 2000
trigger15 = movecontact = 1
trigger16 = stateno = 2100
trigger16 = movecontact = 1
trigger17 = stateno = 800
trigger17 = movecontact = 1
trigger18 = stateno = 810
trigger18 = movecontact = 1
trigger19 = stateno = 820
trigger19 = movecontact = 1
trigger20 = stateno = 800
trigger20 = movecontact = 1
trigger21 = stateno = 1100
trigger21 = movecontact = 1
trigger22 = stateno = 500
trigger22 = movecontact = 1
trigger23 = stateno = 501
trigger23 = movecontact = 1
trigger24 = stateno = 502
trigger24 = movecontact = 1
trigger25 = stateno = 1120
trigger25 = movecontact = 1
trigger26 = stateno = 1130
trigger26 = movecontact = 1
trigger27 = stateno = 1700
trigger27 = movecontact = 1
trigger28 = stateno = 1710
trigger28 = movecontact = 1
trigger29 = stateno = 1720
trigger29 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_Y
[State -1]
type = ChangeState
value = 440
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 450
trigger2 = movecontact = 1
trigger3 = stateno = 440
trigger3 = movecontact = 1
trigger4 = stateno = 430
trigger4 = movecontact = 1
trigger5 = stateno = 420
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 3000
trigger8 = movecontact = 1
trigger9 = stateno = 3200
trigger9 = movecontact = 1
trigger10 = stateno = 3100
trigger10 = movecontact = 1
trigger11 = stateno = 2500
trigger11 = movecontact = 1
trigger12 = stateno = 2510
trigger12 = movecontact = 1
trigger13 = stateno = 2300
trigger13 = movecontact = 1
trigger14 = stateno = 2310
trigger14 = movecontact = 1
trigger15 = stateno = 2000
trigger15 = movecontact = 1
trigger16 = stateno = 2100
trigger16 = movecontact = 1
trigger17 = stateno = 800
trigger17 = movecontact = 1
trigger18 = stateno = 810
trigger18 = movecontact = 1
trigger19 = stateno = 820
trigger19 = movecontact = 1
trigger20 = stateno = 800
trigger20 = movecontact = 1
trigger21 = stateno = 1100
trigger21 = movecontact = 1
trigger22 = stateno = 500
trigger22 = movecontact = 1
trigger23 = stateno = 501
trigger23 = movecontact = 1
trigger24 = stateno = 502
trigger24 = movecontact = 1
trigger25 = stateno = 1120
trigger25 = movecontact = 1
trigger26 = stateno = 1130
trigger26 = movecontact = 1
trigger27 = stateno = 1700
trigger27 = movecontact = 1
trigger28 = stateno = 1710
trigger28 = movecontact = 1
trigger29 = stateno = 1720
trigger29 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_Z
[State -1]
type = ChangeState
value = 450
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 450
trigger2 = movecontact = 1
trigger3 = stateno = 440
trigger3 = movecontact = 1
trigger4 = stateno = 430
trigger4 = movecontact = 1
trigger5 = stateno = 420
trigger5 = movecontact = 1
trigger6 = stateno = 410
trigger6 = movecontact = 1
trigger7 = stateno = 400
trigger7 = movecontact = 1
trigger8 = stateno = 3000
trigger8 = movecontact = 1
trigger9 = stateno = 3200
trigger9 = movecontact = 1
trigger10 = stateno = 3100
trigger10 = movecontact = 1
trigger11 = stateno = 2500
trigger11 = movecontact = 1
trigger12 = stateno = 2510
trigger12 = movecontact = 1
trigger13 = stateno = 2300
trigger13 = movecontact = 1
trigger14 = stateno = 2310
trigger14 = movecontact = 1
trigger15 = stateno = 2000
trigger15 = movecontact = 1
trigger16 = stateno = 2100
trigger16 = movecontact = 1
trigger17 = stateno = 800
trigger17 = movecontact = 1
trigger18 = stateno = 810
trigger18 = movecontact = 1
trigger19 = stateno = 820
trigger19 = movecontact = 1
trigger20 = stateno = 800
trigger20 = movecontact = 1
trigger21 = stateno = 1100
trigger21 = movecontact = 1
trigger22 = stateno = 500
trigger22 = movecontact = 1
trigger23 = stateno = 501
trigger23 = movecontact = 1
trigger24 = stateno = 502
trigger24 = movecontact = 1
trigger25 = stateno = 1120
trigger25 = movecontact = 1
trigger26 = stateno = 1130
trigger26 = movecontact = 1
trigger27 = stateno = 1700
trigger27 = movecontact = 1
trigger28 = stateno = 1710
trigger28 = movecontact = 1
trigger29 = stateno = 1720
trigger29 = movecontact = 1

;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 600
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 610
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_C
[State -1]
type = ChangeState
value = 620
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 630
triggerall = command = "x"
triggerall = Vel X = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_X (moving)
[State -1]
type = ChangeState
value = 635
triggerall = command = "x"
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 640
triggerall = command = "y"
triggerall = Vel X = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Y (moving)
[State -1]
type = ChangeState
value = 645
triggerall = command = "y"
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Z
[State -1]
type = ChangeState
value = 650
triggerall = command = "z"
triggerall = Vel X = 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_Z (moving)
[State -1]
type = ChangeState
value = 655
triggerall = command = "z"
triggerall = Vel X != 0
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Taunt
[State -1]
type = ChangeState
value = 196
triggerall = p2life <= 200
trigger1 = command = "s"
trigger1 = command = "holdfwd"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Taunt
[State -1]
type = ChangeState
value = 197
triggerall = p2life <= 200
trigger1 = command = "s"
trigger1 = command = "holdback"
trigger1 = statetype = S
trigger1 = ctrl = 1

;Taunt
[State -1]
type = ChangeState
value = 195
trigger1 = command = "s"
trigger1 = statetype = S
trigger1 = ctrl = 1

